from setuptools import setup

setup(name='distgaubin',
      version='0.1',
      description='Gaussian and Binomial distributions',
      packages=['distgaubin'],
      author = "AnmolJM",
      author_email = 'anmoljm@gmail.com',
      zip_safe=False)
